@@ -496,15 +496,68 @@ class SQLEditor(QPlainTextEdit):
         popup = self.completer.popup()
         popup.setCurrentIndex(self.completer.completionModel().index(0, 0))
         
-        # Calculate position for the popup
-        cr = self.cursorRect()
-        cr.setWidth(self.completer.popup().sizeHintForColumn(0) + 
-                   self.completer.popup().verticalScrollBar().sizeHint().width())
-        
-        # Show the popup
-        self.completer.complete(cr)
+        try:
+            # Calculate position for the popup
+            cr = self.cursorRect()
+            
+            # Ensure cursorRect is valid
+            if not cr.isValid() or cr.x() < 0 or cr.y() < 0:
+                # Try to recompute using the text cursor
+                cursor = self.textCursor()
+                cr = self.cursorRect(cursor)
+                
+                # If still invalid, use a default position
+                if not cr.isValid() or cr.x() < 0 or cr.y() < 0:
+                    pos = self.mapToGlobal(self.pos())
+                    cr = QRect(pos.x() + 10, pos.y() + 10, 10, self.fontMetrics().height())
+            
+            # Calculate width for the popup that fits the content
+            suggested_width = popup.sizeHintForColumn(0) + popup.verticalScrollBar().sizeHint().width()
+            # Ensure minimum width
+            popup_width = max(suggested_width, 200)
+            cr.setWidth(popup_width)
+            
+            # Show the popup at the correct position
+            self.completer.complete(cr)
+        except Exception as e:
+            # In case of any error, try a more direct approach
+            print(f"Error positioning completion popup: {e}")
+            try:
+                cursor_pos = self.mapToGlobal(self.cursorRect().bottomLeft())
+                popup.move(cursor_pos)
+                popup.show()
+            except:
+                # Last resort - if all else fails, hide the popup to avoid showing it in the wrong place
+                popup.hide()
 
     def keyPressEvent(self, event):
+        # Check for Ctrl+Enter first, which should take precedence over other behaviors
+        if event.key() == Qt.Key.Key_Return and (event.modifiers() & Qt.KeyboardModifier.ControlModifier):
+            # If autocomplete popup is showing, hide it
+            if self.completer and self.completer.popup().isVisible():
+                self.completer.popup().hide()
+            
+            # Cancel any pending autocomplete timers
+            if hasattr(self, '_completion_timer') and self._completion_timer.isActive():
+                self._completion_timer.stop()
+            
+            # Let the main window handle query execution
+            # Important: We need to emit event to parent to trigger execution
+            # and prevent it from being treated as an autocomplete selection
+            event.accept()  # Mark the event as handled
+            
+            # Find the parent SQLShell instance and call its execute_query method
+            parent = self
+            while parent is not None:
+                if hasattr(parent, 'execute_query'):
+                    parent.execute_query()
+                    return
+                parent = parent.parent()
+                
+            # If we couldn't find the execute_query method, pass the event up
+            super().keyPressEvent(event)
+            return
+        
         # Handle completer popup navigation
         if self.completer and self.completer.popup().isVisible():
             # Handle Tab key to complete the current selection
@@ -816,11 +869,15 @@ class SQLEditor(QPlainTextEdit):
             # Get table name from dropped text
             text = event.mimeData().text()
             
-            # Extract actual table name (if it includes parentheses)
-            if " (" in text:
-                table_name = text.split(" (")[0]
+            # Try to extract table name from custom mime data if available
+            if event.mimeData().hasFormat('application/x-sqlshell-tablename'):
+                table_name = bytes(event.mimeData().data('application/x-sqlshell-tablename')).decode()
             else:
-                table_name = text
+                # Extract actual table name (if it includes parentheses)
+                if " (" in text:
+                    table_name = text.split(" (")[0]
+                else:
+                    table_name = text
                 
             # Get current cursor position and surrounding text
             cursor = self.textCursor()
