@@ -1,5 +1,5 @@
 from PyQt6.QtWidgets import (QHeaderView, QMenu, QCheckBox, QWidgetAction, 
-                           QWidget, QVBoxLayout, QLineEdit, QHBoxLayout, QPushButton, QTableWidget)
+                           QWidget, QVBoxLayout, QLineEdit, QHBoxLayout, QPushButton, QTableWidget, QMessageBox)
 from PyQt6.QtCore import Qt, QRect, QPoint
 from PyQt6.QtGui import QColor, QFont, QPolygon, QPainterPath, QBrush
 
@@ -90,9 +90,15 @@ class FilterHeader(QHeaderView):
         sort_desc_action = context_menu.addAction("Sort Descending")
         context_menu.addSeparator()
         
+        # Add count rows action
+        count_rows_action = context_menu.addAction("Count Rows")
+        
         # Add explain column action
         explain_action = context_menu.addAction("Explain Column")
         
+        # Add encode text action
+        encode_action = context_menu.addAction("Encode Text")
+        
         context_menu.addSeparator()
         filter_action = context_menu.addAction("Filter...")
         
@@ -141,6 +147,21 @@ class FilterHeader(QHeaderView):
                     if logical_index < len(current_tab.current_df.columns):
                         column_name = current_tab.current_df.columns[logical_index]
                         self.main_window.explain_column(column_name)
+        elif action == encode_action:
+            # Call the encode_text method on the main window
+            if self.main_window and hasattr(self.main_window, "encode_text"):
+                # Get the column name from the table (if it has a current dataframe)
+                current_tab = self.main_window.get_current_tab()
+                if current_tab and hasattr(current_tab, "current_df") and current_tab.current_df is not None:
+                    if logical_index < len(current_tab.current_df.columns):
+                        column_name = current_tab.current_df.columns[logical_index]
+                        self.main_window.encode_text(column_name)
+        elif action == count_rows_action:
+            # Get the current tab and show row count
+            current_tab = self.main_window.get_current_tab()
+            if current_tab and hasattr(current_tab, "current_df") and current_tab.current_df is not None:
+                row_count = len(current_tab.current_df)
+                QMessageBox.information(self, "Row Count", f"Total rows: {row_count:,}")
 
     def set_main_window(self, window):
         """Set the reference to the main window"""
